#!/usr/bin/env python3
"""
Setup script for Persona-Based Conversation Generator CLI
"""

from setuptools import setup, find_packages
import os

# Read the README file
def read_readme():
    with open("README.md", "r", encoding="utf-8") as fh:
        return fh.read()

# Read requirements

def read_requirements():
    try:
        with open("requirements.txt", "r", encoding="utf-8") as fh:
            return [line.strip() for line in fh if line.strip() and not line.startswith("#")]
    except FileNotFoundError:
        print("Warning: requirements.txt not found. No install_requires will be set.")
        return []

setup(
    name="persona-chat",
    version="0.1.1",
    author="Persona Chat Team",
    author_email="team@persona-chat.com",
    description="A sophisticated CLI application for generating authentic multi-turn conversations using 50+ distinct user personas",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/your-org/persona-chat",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing :: Linguistic",
    ],
    python_requires=">=3.8",
    install_requires=read_requirements(),
    extras_require={
        "dev": [
            "pytest>=7.0.0",
            "pytest-cov>=4.0.0",
            "pytest-mock>=3.10.0",
            "black>=23.0.0",
            "flake8>=6.0.0",
            "mypy>=1.0.0",
            "sphinx>=6.0.0",
            "sphinx-rtd-theme>=1.2.0",
        ],
        "ml": [
            "scikit-learn>=1.3.0",
            "transformers>=4.30.0",
            "torch>=2.0.0",
        ],
        "llm": [
            "openai>=1.0.0",
            "transformers>=4.30.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "persona-chat=persona_chat.cli.main:main",
        ],
    },
    include_package_data=True,
    package_data={
        "persona_chat": [
            "config/**/*.yaml",
            "config/**/*.yml",
        ],
    },
    keywords="conversation generation, personas, multi-language, CLI, AI, NLP",
    project_urls={
        "Bug Reports": "https://github.com/your-org/persona-chat/issues",
        "Source": "https://github.com/your-org/persona-chat",
        "Documentation": "https://persona-chat.readthedocs.io/",
    },
) 